# cdprox

cdprox is a Python package for adding DNS records to Cloudflare and configuring Caddy reverse proxies.

Install caddy server (no docker)

then 

CLOUDFLARE_API_TOKEN='ibU8C0_AwVW' #use own
export CLOUDFLARE_ZONE_ID='234234234' #use own


## Installation

```bash
pip install .
